/*
********************************************************************
* IBM Confidential                                                 *
*                                                                  *
* OCO Source Materials                                             *
*                                                                  *
* 5724-E76 and 5724-E77                                            *
*                                                                  *
* (C) Copyright IBM Corp. 2001, 2003, 2004                         *
*                                                                  *
* The source code for this program is not published or otherwise   *
* divested of its trade secrets, irrespective of what has been     *
* deposited with the U.S. Copyright Office.                        *
********************************************************************
*/
package com.ibm.portal.um.portletservice;

import com.ibm.portal.um.PumaController;
import com.ibm.portal.um.PumaLocator;
import com.ibm.portal.um.PumaProfile;

/**
 * This Interface can be used to access the UserManagement component of WebSphere Portal <br>
 * from a JSR 168 portlet. An instance can be retrieved using a JNDI lookup for the following  JNDI name
 * <code>portletservice/com.ibm.portal.um.portletservice.PumaHome</code> 
 *
 * The returned instance provides a way to access the three views to the user repository<br> 
 * 
 * <Code>com.ibm.portal.um.PumaProfile</CODE> <br>
 * <Code>com.ibm.portal.um.PumaController</CODE> <br>
 * <Code>com.ibm.portal.um.PumaLocator</CODE> <br>
 *
 * The following sample shows you how to perform the JNDI lookup
 * 
 * <pre>
 *     PortletServiceHome psh;
 *     javax.naming.Context ctx = new javax.naming.InitialContext();
 *     try {
 *          psh = (PortletServiceHome) 
 *             ctx.lookup("portletservice/com.ibm.portal.um.portletservice.PumaHome");
 *     } catch(javax.naming.NameNotFoundException ex) {
 *          ... error handling ...
 *     }
 *     ...
 *     // use the service
 *     PumaHome service = (PumaHome) psh.getPortletService(PumaHome.class);
 * </pre>
 * 
 * 
 * @see com.ibm.portal.um.PumaProfile
 * @see com.ibm.portal.um.PumaLocator
 * @see com.ibm.portal.um.PumaController
 * 
 * @ibm-spi
 * @since 5.1.0.1  
 */
public interface PumaHome extends com.ibm.portal.portlet.service.PortletService
{
           
    /**
     * The returned instance of <Code>PumaController</COde> can be used to read/modify attributes
     * for a <code>Principal</CODE>
     *  
     * @param aRequest <code>NULL</CODE> is not allowed as parameter
     * @return a handle to the read/write PUMA service
     */
    PumaController getController(javax.portlet.ActionRequest aRequest);
    
    /**
     * The returned instance of <Code>PumaLocator</COde> can be used find <code>Principal</CODE>
     *  
     * @param aRequest <code>NULL</CODE> is not allowed as parameter
     * @return a handle to the find PUMA service
     */
    PumaLocator getLocator(javax.portlet.PortletRequest aRequest);
    
    /**
     * The returned instance of <Code>PumaProfile</COde> can be used to read attributes
     * for a <code>Principal</CODE>
     *  
     * @param aRequest <code>NULL</CODE> is not allowed as parameter
     * @return a handle to the read PUMA service
     */
    PumaProfile getProfile(javax.portlet.PortletRequest aRequest);
       

}
