/*
********************************************************************
* IBM Confidential                                                 *
*                                                                  *
* OCO Source Materials                                             *
*                                                                  *
* 5724-E76 and 5724-E77                                            *
*                                                                  *
* (C) Copyright IBM Corp. 2001, 2003                               *
*                                                                  *
* The source code for this program is not published or otherwise   *
* divested of its trade secrets, irrespective of what has been     *
* deposited with the U.S. Copyright Office.                        *
********************************************************************
*/
package com.ibm.wps.portletservice.portletmenu;

import org.apache.jetspeed.portlet.service.PortletService;

import com.ibm.wps.portlet.menu.MenuTree;

/**
 * <P>The <CODE>LogMenuService</CODE> service creates a logging version of a menu tree for debugging purposes.
 * All calls to all exposed interfaces will automatically be logged to the
 * standard {@link Logger} output. Create your desired menu tree first and wrap it with the log menu tree.</P>
 * <P>
 * <P>For an overview of Portlet Menus, start with {@link com.ibm.wps.portlet.menu.MenuProvider}.</P>
 * <P><B>Code example:</B></P>
 * <PRE>
 * // service for tree logging
 * LogMenuService logService=null;
 * 
 * try
 * {
 *     logService = (LogMenuService) portletContext.getService(LogMenuService.class);
 * }
 * catch ( PortletServiceUnavailableException e )
 * {
 *     throw new PortletException ("MemoryMenuTreePortlet: Exception: The LogMenuService is unavailable");
 * }
 * catch ( PortletServiceNotFoundException e )
 * {
 *     throw new PortletException ("MemoryMenuTreePortlet: Exception: The LogMenuService has not been found");
 * }
 * 
 * // wrap tree
 * try
 * {
 *     // service for tree logging
 *     wrappedMenuTree = logService.getMenuTree(menuTree);
 * }
 * catch ( MenuTreeException mte )
 * {
 *     throw new PortletException ("MemoryMenuTreePortlet: Exception getting menu tree from service");
 * }
 * </PRE>
 * </P>
 * 
 * @ibm-spi
 * @since 5.0
 */

public interface LogMenuService extends PortletService
{
    /**
     * Creates a menu tree that logs all method calls on top of
     * an existing tree using the standard {@link Logger} output.
     * 
     * @param parent menu tree to be observed
     * 
     * @return the same menu tree as specified as parameter <CODE>parent</CODE>.
     *         Additionaly, logging information is sent to the standard {@link Logger} output.
     */
    public MenuTree getMenuTree(MenuTree parent);
}


